import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataKubernetesIngressV1Config extends cdktf.TerraformMetaArguments {
    /**
    * metadata block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress_v1#metadata DataKubernetesIngressV1#metadata}
    */
    readonly metadata: DataKubernetesIngressV1Metadata;
}
export declare class DataKubernetesIngressV1SpecDefaultBackendResource extends cdktf.ComplexComputedList {
    get apiGroup(): string;
    get kind(): string;
    get name(): string;
}
export declare class DataKubernetesIngressV1SpecDefaultBackendServicePort extends cdktf.ComplexComputedList {
    get name(): string;
    get number(): number;
}
export declare class DataKubernetesIngressV1SpecDefaultBackendService extends cdktf.ComplexComputedList {
    get name(): string;
    get port(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressV1SpecDefaultBackend extends cdktf.ComplexComputedList {
    get resource(): cdktf.IResolvable;
    get service(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressV1SpecRuleHttpPathBackendResource extends cdktf.ComplexComputedList {
    get apiGroup(): string;
    get kind(): string;
    get name(): string;
}
export declare class DataKubernetesIngressV1SpecRuleHttpPathBackendServicePort extends cdktf.ComplexComputedList {
    get name(): string;
    get number(): number;
}
export declare class DataKubernetesIngressV1SpecRuleHttpPathBackendService extends cdktf.ComplexComputedList {
    get name(): string;
    get port(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressV1SpecRuleHttpPathBackend extends cdktf.ComplexComputedList {
    get resource(): cdktf.IResolvable;
    get service(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressV1SpecRuleHttpPath extends cdktf.ComplexComputedList {
    get backend(): cdktf.IResolvable;
    get path(): string;
    get pathType(): string;
}
export declare class DataKubernetesIngressV1SpecRuleHttp extends cdktf.ComplexComputedList {
    get path(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressV1SpecRule extends cdktf.ComplexComputedList {
    get host(): string;
    get http(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressV1SpecTls extends cdktf.ComplexComputedList {
    get hosts(): string[];
    get secretName(): string;
}
export declare class DataKubernetesIngressV1Spec extends cdktf.ComplexComputedList {
    get defaultBackend(): cdktf.IResolvable;
    get ingressClassName(): string;
    get rule(): cdktf.IResolvable;
    get tls(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressV1StatusLoadBalancerIngress extends cdktf.ComplexComputedList {
    get hostname(): string;
    get ip(): string;
}
export declare class DataKubernetesIngressV1StatusLoadBalancer extends cdktf.ComplexComputedList {
    get ingress(): cdktf.IResolvable;
}
export declare class DataKubernetesIngressV1Status extends cdktf.ComplexComputedList {
    get loadBalancer(): cdktf.IResolvable;
}
export interface DataKubernetesIngressV1Metadata {
    /**
    * An unstructured key value map stored with the ingress that may be used to store arbitrary metadata. More info: http://kubernetes.io/docs/user-guide/annotations
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress_v1#annotations DataKubernetesIngressV1#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Map of string keys and values that can be used to organize and categorize (scope and select) the ingress. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress_v1#labels DataKubernetesIngressV1#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Name of the ingress, must be unique. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress_v1#name DataKubernetesIngressV1#name}
    */
    readonly name?: string;
    /**
    * Namespace defines the space within which name of the ingress must be unique.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress_v1#namespace DataKubernetesIngressV1#namespace}
    */
    readonly namespace?: string;
}
export declare function dataKubernetesIngressV1MetadataToTerraform(struct?: DataKubernetesIngressV1MetadataOutputReference | DataKubernetesIngressV1Metadata): any;
export declare class DataKubernetesIngressV1MetadataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataKubernetesIngressV1Metadata | undefined;
    set internalValue(value: DataKubernetesIngressV1Metadata | undefined);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get generation(): number;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    get resourceVersion(): string;
    get uid(): string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress_v1 kubernetes_ingress_v1}
*/
export declare class DataKubernetesIngressV1 extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/kubernetes/d/ingress_v1 kubernetes_ingress_v1} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataKubernetesIngressV1Config
    */
    constructor(scope: Construct, id: string, config: DataKubernetesIngressV1Config);
    get id(): string;
    spec(index: string): DataKubernetesIngressV1Spec;
    status(index: string): DataKubernetesIngressV1Status;
    private _metadata;
    get metadata(): DataKubernetesIngressV1MetadataOutputReference;
    putMetadata(value: DataKubernetesIngressV1Metadata): void;
    get metadataInput(): DataKubernetesIngressV1Metadata | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
